@@ -1,7 +1,7 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
@@ -36,11 +36,11 @@ NAN_METHOD(Check) {
 NAN_MODULE_INIT(Init) {
   Set(target
     , New<v8::String>("hook").ToLocalChecked()
-    , New<v8::FunctionTemplate>(Hook)->GetFunction()
+    , GetFunction(New<v8::FunctionTemplate>(Hook)).ToLocalChecked()
   );
   Set(target
     , New<v8::String>("check").ToLocalChecked()
-    , New<v8::FunctionTemplate>(Check)->GetFunction()
+    , GetFunction(New<v8::FunctionTemplate>(Check)).ToLocalChecked()
   );
 }
 
