@@ -1,7 +1,7 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
@@ -31,7 +31,7 @@ NAN_METHOD(SetAndGet) {
 NAN_MODULE_INIT(Init) {
   Set(target
     , New<v8::String>("setAndGet").ToLocalChecked()
-    , New<v8::FunctionTemplate>(SetAndGet)->GetFunction()
+    , GetFunction(New<v8::FunctionTemplate>(SetAndGet)).ToLocalChecked()
   );
 }
 
