@@ -114,7 +114,11 @@ NAN_METHOD(NewScript) {
 }
 
 NAN_METHOD(NewScript2) {
-  v8::ScriptOrigin origin(New<v8::String>("x").ToLocalChecked());
+  v8::ScriptOrigin origin(
+#if NODE_MODULE_VERSION >= NODE_18_0_MODULE_VERSION
+    info.GetIsolate(),
+#endif
+    New<v8::String>("x").ToLocalChecked());
   v8::Local<UnboundScript> script =
       New<UnboundScript>(
           New("2+4").ToLocalChecked()
@@ -131,7 +135,11 @@ NAN_METHOD(CompileScript) {
 }
 
 NAN_METHOD(CompileScript2) {
-  v8::ScriptOrigin origin(New<v8::String>("x").ToLocalChecked());
+  v8::ScriptOrigin origin(
+#if NODE_MODULE_VERSION >= NODE_18_0_MODULE_VERSION
+    info.GetIsolate(),
+#endif
+    New<v8::String>("x").ToLocalChecked());
   v8::Local<BoundScript> script =
       CompileScript(New("2+4").ToLocalChecked(), origin).ToLocalChecked();
   info.GetReturnValue().Set(
