@@ -1,7 +1,7 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
@@ -33,11 +33,12 @@ NAN_METHOD(CallAsFunctionHandlerSetter) {
 NAN_MODULE_INIT(Init) {
   Set(target
     , New("a").ToLocalChecked()
-    , New<v8::FunctionTemplate>(CallHandlerSetter)->GetFunction()
+    , GetFunction(New<v8::FunctionTemplate>(CallHandlerSetter)).ToLocalChecked()
   );
   Set(target
     , New("b").ToLocalChecked()
-    , New<v8::FunctionTemplate>(CallAsFunctionHandlerSetter)->GetFunction()
+    , GetFunction(New<v8::FunctionTemplate>(CallAsFunctionHandlerSetter))
+        .ToLocalChecked()
   );
 }
 
